@@ -6,9 +6,10 @@ from django.contrib.auth.models import User
 from django.core.management import call_command
 from django.db import connection, transaction
 from django.test.utils import override_settings
+from django.utils.version import get_main_version, get_version_tuple
 
 from django_tenants.clone import CloneSchema
-from django_tenants.signals import schema_migrated, schema_migrate_message
+from django_tenants.signals import schema_migrated, schema_migrate_message, schema_pre_migration
 from dts_test_app.models import DummyModel, ModelWithFkToPublicUser
 
 from django_tenants.migration_executors import get_executor
@@ -190,7 +191,7 @@ class TenantDataAndSettingsTest(BaseTestCase):
         DummyModel(name="awesome!").save()
 
         # switch temporarily to tenant2's path
-        with self.assertNumQueries(6):
+        with self.assertNumQueries(3):
             with tenant_context(tenant2):
                 # add some data, 3 DummyModels for tenant2
                 DummyModel(name="Man,").save()
@@ -198,11 +199,11 @@ class TenantDataAndSettingsTest(BaseTestCase):
                 DummyModel(name="is great!").save()
 
         # we should be back to tenant1's path, test what we have
-        with self.assertNumQueries(2):
+        with self.assertNumQueries(1):
             self.assertEqual(2, DummyModel.objects.count())
 
         # switch back to tenant2's path
-        with self.assertNumQueries(2):
+        with self.assertNumQueries(1):
             with tenant_context(tenant2):
                 self.assertEqual(3, DummyModel.objects.count())
 
@@ -229,8 +230,7 @@ class TenantDataAndSettingsTest(BaseTestCase):
             connection.set_tenant(tenant1)
 
         # switch temporarily to tenant2's path
-        # 1 query to set search path + 3 to save data
-        with self.assertNumQueries(4):
+        with self.assertNumQueries(3):
             with tenant_context(tenant2):
                 DummyModel(name="Man,").save()
                 DummyModel(name="testing").save()
@@ -240,16 +240,14 @@ class TenantDataAndSettingsTest(BaseTestCase):
         with self.assertNumQueries(0):
             connection.set_tenant(tenant1)
 
-        # 1 set search path + 1 count
-        with self.assertNumQueries(2):
+        with self.assertNumQueries(1):
             self.assertEqual(0, DummyModel.objects.count())
 
         # 0 queries as search path not set here
         with self.assertNumQueries(0):
             connection.set_tenant(tenant2)
 
-        # 1 set search path + 1 count
-        with self.assertNumQueries(2):
+        with self.assertNumQueries(1):
             self.assertEqual(3, DummyModel.objects.count())
 
         self.created = [domain2, domain1, tenant2, tenant1]
@@ -336,17 +334,6 @@ class BaseSyncTest(BaseTestCase):
                    'django.contrib.contenttypes', )  # 1 table
     TENANT_APPS = ('django.contrib.sessions', )
 
-    @classmethod
-    def setUpClass(cls):
-        super().setUpClass()
-        cls.INSTALLED_APPS = cls.SHARED_APPS + cls.TENANT_APPS
-
-        settings.SHARED_APPS = cls.SHARED_APPS
-        settings.TENANT_APPS = cls.TENANT_APPS
-        settings.INSTALLED_APPS = cls.INSTALLED_APPS
-
-        cls.available_apps = cls.INSTALLED_APPS
-
     def setUp(self):
         super().setUp()
         # Django calls syncdb by default for the test database, but we want
@@ -397,9 +384,15 @@ class TestSyncTenantsWithAuth(BaseSyncTest):
                    'django.contrib.sessions', )  # 1 table
     TENANT_APPS = ('django.contrib.sessions', )  # 1 table
 
-    def _pre_setup(self):
-        self.sync_shared()
-        super()._pre_setup()
+    if get_version_tuple(get_main_version()) < (5, 2):
+        def _pre_setup(self):
+            self.sync_shared()
+            super()._pre_setup()
+    else:
+        @classmethod
+        def _pre_setup(cls):
+            cls.sync_shared()
+            super()._pre_setup()
 
     def test_tenant_apps_and_shared_apps_can_have_the_same_apps(self):
         """
@@ -685,10 +678,15 @@ class SchemaMigratedSignalTest(BaseTestCase):
         Public schema always gets migrated in the current process,
         even with executor multiprocessing.
         """
-        with catch_signal(schema_migrated) as handler:
+        with catch_signal(schema_migrated) as handler_post, catch_signal(schema_pre_migration) as handler_pre:
             self.sync_shared()
 
-        handler.assert_called_once_with(
+        handler_pre.assert_called_once_with(
+            schema_name=get_public_schema_name(),
+            sender=mock.ANY,
+            signal=schema_pre_migration,
+        )
+        handler_post.assert_called_once_with(
             schema_name=get_public_schema_name(),
             sender=mock.ANY,
             signal=schema_migrated,
@@ -702,11 +700,16 @@ class SchemaMigratedSignalTest(BaseTestCase):
         executor = get_executor()
 
         tenant = get_tenant_model()(schema_name='test')
-        with catch_signal(schema_migrated) as handler:
+        with catch_signal(schema_migrated) as handler_post, catch_signal(schema_pre_migration) as handler_pre:
             tenant.save()
 
         if executor == 'simple':
-            handler.assert_called_once_with(
+            handler_pre.assert_called_once_with(
+                schema_name='test',
+                sender=mock.ANY,
+                signal=schema_pre_migration
+            )
+            handler_post.assert_called_once_with(
                 schema_name='test',
                 sender=mock.ANY,
                 signal=schema_migrated
@@ -714,7 +717,8 @@ class SchemaMigratedSignalTest(BaseTestCase):
         elif executor == 'multiprocessing':
             # migrations run in a different process, therefore signal
             # will get sent in a different process as well
-            handler.assert_not_called()
+            handler_post.assert_not_called()
+            handler_pre.assert_not_called()
 
         domain = get_tenant_domain_model()(tenant=tenant, domain='something.test.com')
         domain.save()
@@ -731,11 +735,22 @@ class SchemaMigratedSignalTest(BaseTestCase):
         domain.save()
 
         # test the signal gets called when running migrate
-        with catch_signal(schema_migrated) as handler:
+        with catch_signal(schema_migrated) as handler_post, catch_signal(schema_pre_migration) as handler_pre:
             call_command('migrate_schemas', interactive=False, verbosity=0)
 
         if executor == 'simple':
-            handler.assert_has_calls([
+            handler_pre.assert_has_calls([
+                mock.call(
+                    schema_name=get_public_schema_name(),
+                    sender=mock.ANY,
+                    signal=schema_pre_migration,
+                ),
+                mock.call(
+                    schema_name='test',
+                    sender=mock.ANY,
+                    signal=schema_pre_migration)
+            ])
+            handler_post.assert_has_calls([
                 mock.call(
                     schema_name=get_public_schema_name(),
                     sender=mock.ANY,
@@ -748,7 +763,12 @@ class SchemaMigratedSignalTest(BaseTestCase):
             ])
         elif executor == 'multiprocessing':
             # public schema gets migrated in the current process, always
-            handler.assert_called_once_with(
+            handler_pre.assert_called_once_with(
+                schema_name=get_public_schema_name(),
+                sender=mock.ANY,
+                signal=schema_pre_migration,
+            )
+            handler_post.assert_called_once_with(
                 schema_name=get_public_schema_name(),
                 sender=mock.ANY,
                 signal=schema_migrated,
@@ -797,10 +817,22 @@ class MigrationOrderTestTest(BaseTestCase):
         )
 
         # test the signal gets called when running migrate
-        with catch_signal(schema_migrated) as handler:
+        with catch_signal(schema_migrated) as handler_post, catch_signal(schema_pre_migration) as handler_pre:
             call_command("migrate_schemas", interactive=False, verbosity=0)
 
-        handler.assert_has_calls(
+        handler_pre.assert_has_calls(
+            [
+                mock.call(
+                    schema_name=get_public_schema_name(),
+                    sender=mock.ANY,
+                    signal=schema_pre_migration,
+                ),
+                mock.call(schema_name="xtest", sender=mock.ANY, signal=schema_pre_migration),
+                mock.call(schema_name="test", sender=mock.ANY, signal=schema_pre_migration),
+            ]
+        )
+
+        handler_post.assert_has_calls(
             [
                 mock.call(
                     schema_name=get_public_schema_name(),
